<?php

use Tygh\Http;
use Tygh\Registry;

if (!defined('BOOTSTRAP')) { die('Access denied'); }

if ($_SERVER['REQUEST_METHOD'] == 'POST') {

    return;

}

if ($mode == 'transfer_data') {
	
    $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

    if (!empty($routee_uuid)) {
        
        fn_set_notification('N', __('notice'), __('routee.already_authorized'));
        exit;
        
    }
    
    $auth_data = array(
        'username' => Registry::get('addons.routee.username'),
        'password' => Registry::get('addons.routee.password'),
        'source' => 'CSCart',
        'type' => 'e-commerce',
        'version' => PRODUCT_VERSION,
        'plugin_version' => '1.3.0',
        'domain' => Registry::get('config.current_location'),
    );
    $return = json_decode(Http::post('https://waymore.routee.net/api/authenticate', json_encode($auth_data)), true);
    
    if (isset($return['uuid']) && !empty($return['uuid'])) {
        
        $_data = array(
            'object_id' => '1',
            'lang_code' => 'en',
            'description' => $return['uuid'],
            'object_holder' => 'routee_uuid'
        );
        db_query('REPLACE INTO ?:common_descriptions ?e', $_data);
        
        fn_set_notification('N', __('notice'), __('routee.authorization_successful'));
        
    } else {
        
        fn_set_notification('E', __('error'), __('routee.authorization_refused'));
        exit;
        
    }

	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

	if (empty($routee_uuid)) {
		exit;
	}
	
	// transfer products
	
	fn_set_progress('echo', 'Preparing products...', false);
	
	list($products, $search) = fn_get_products(array('extend' => array('description')));
	fn_gather_additional_products_data($products, array(
		'get_icon' => true,
		'get_detailed' => true,
		'get_additional' => true,
		'get_options' => true,
		'get_discounts' => false,
		'get_features' => false
	));
	
	fn_set_progress('parts', $search['total_items']);
	
	if (!empty($products)) {
		
		$p = 0;
		$i = 0;
		
		$mass_data = array(
			'uuid' => $routee_uuid,
			'data' => array(
				array(
					'name' => 'products',
					'description' => 'shop products'
				)
			)
		);
		
		foreach ($products as $v) {
			
			$mass_data['data'][0]['object'][$i] = array(
				'product_id' => $v['product_id'],
				'name' => $v['product'],
				'description' => $v['full_description'],
				'short_description' => $v['short_description'],
				'stock_quantity' => $v['amount'],
				'price' => $v['price'],
				'image_link' => (!empty($v['main_pair'])) ? $v['main_pair']['detailed']['image_path'] : '',
				'product_link' => fn_url('products.view?product_id='.$v['product_id'], 'C'),
			);
			if (!empty($v['category_ids'])) {
				foreach ($v['category_ids'] as $vv) {
					$mass_data['data'][0]['object'][$i]['categories'][] = fn_get_category_name($vv);
				}
			}
			if (!empty($v['product_options'])) {
				foreach ($v['product_options'] as $opt) {
					if (!empty($opt['variants'])) {
						foreach ($opt['variants'] as $var) {
							$mass_data['data'][0]['object'][$i]['product_options'][] = array(
								'option_id' => $opt['option_id'],
								'option_name' => $opt['option_name'],
								'varian_name' => $var['variant_name'],
								'price_modifier' => $var['modifier'],
							);
						}
					}
				}
			}
	
			$i++;
			$p++;
			fn_set_progress('echo','Transferring products... '.$p.' of '.$search['total_items']);
	
			if ($i == 100 || $p == $search['total_items']) {
	
				$return = Http::post('https://idata.routee.net/api/data', json_encode($mass_data));

				$i = 0;
				$mass_data['data'][0]['object'] = array();
	
			}
			
		}
		
	}
	
	// transfer customers
	
	fn_set_progress('echo', 'Preparing customers...', false);
	
	list($users, $search) = fn_get_users(array(), $_SESSION['auth']);
	
	if (!empty($users)) {
		
		fn_set_progress('parts', sizeof($users));
		
		$u = 0;
		$i = 0;
		$total_users = sizeof($users);
		
		$mass_data = array(
			'uuid' => $routee_uuid,
			'data' => array(
				array(
					'name' => 'customers',
					'description' => 'shop customers'
				)
			)
		);
		
		foreach ($users as $v) {
			
			$user_data = fn_get_user_info($v['user_id']);
	
			$mass_data['data'][0]['object'][$i] = array(
				'customer' => array(
					'id' => $user_data['user_id'],
					'lastname' => $user_data['firstname'],
					'firstname' => $user_data['lastname'],
					'email' => $user_data['email'],
					'phone' => $user_data['phone'],
				),
				'addresses' => array(
					array(
						'country' => $user_data['b_country_descr'],
						'city' => $user_data['b_city'],
						'address1' => $user_data['b_address'],
						'postcode' => $user_data['b_zipcode'],
						'company' => $user_data['company'],
					)
				)
			);
			
			$i++;
			$u++;
			fn_set_progress('echo','Transferring users... '.$u.' of '.$total_users);
	
			if ($i == 100 || $u == $total_users) {
	
				$return = Http::post('https://idata.routee.net/api/data', json_encode($mass_data));
	
				$i = 0;
				$mass_data['data'][0]['object'] = array();
	
			}
	
		}
	
	}
	
	// transfer orders
	
	fn_set_progress('echo', 'Preparing orders...', false);
	
	list($orders, $search) = fn_get_orders(array());

	if (!empty($orders)) {

		$o = 0;
		$i = 0;
		$total_orders = sizeof($orders);
		
		fn_set_progress('parts', $total_orders);
		
		$mass_data = array(
			'uuid' => $routee_uuid,
			'data' => array(
				array(
					'name' => 'orders',
					'description' => 'shop orders'
				)
			)
		);
		
		foreach ($orders as $v) {
			
			$order_info = fn_get_order_info($v['order_id'], false, true, false, false);

			$mass_data['data'][0]['object'][$i] = array(
				'order_details' => array(
					'order_id' => $order_info['user_id'],
					'order_status' => db_get_field('SELECT ?:status_descriptions.description FROM ?:status_descriptions LEFT JOIN ?:statuses ON ?:status_descriptions.status_id = ?:statuses.status_id WHERE ?:statuses.status = ?s AND ?:statuses.type = ?s AND ?:status_descriptions.lang_code = ?s', ($order_info['status'] == 'N') ? 'O' : $order_info['status'], 'O', CART_LANGUAGE),
					'shipping_method' => db_get_field('SELECT ?:shipping_descriptions.shipping FROM ?:shipping_descriptions LEFT JOIN ?:shippings ON ?:shippings.shipping_id = ?:shippings.shipping_id WHERE ?:shippings.shipping_id = ?i AND ?:shipping_descriptions.lang_code = ?s', $order_info['shipping_ids'], CART_LANGUAGE),
					'payment_method' => isset($order_info['payment_method']['payment']) ? $order_info['payment_method']['payment'] : '',
					'total_price' => $order_info['total'],
				)
			);
			if (!empty($order_info['products'])) {
				foreach ($order_info['products'] as $v) {
					$mass_data['data'][0]['object'][$i]['order_products'][] = array(
						'product_id' => $v['product_id'],
						'quantity' => $v['amount'],
					);
				}
			}

			$i++;
			$o++;
			fn_set_progress('echo','Transferring orders... '.$o.' of '.$total_orders);
	
			if ($i == 100 || $o == $total_orders) {
	
				$return = Http::post('https://idata.routee.net/api/data', json_encode($mass_data));

				$i = 0;
				$mass_data['data'][0]['object'] = array();
	
			}

		}

	}

	fn_set_notification('N', __('notice'), __('done'));
	exit;
	
}
