<?php

use Tygh\Http;
use Tygh\Registry;

function fn_routee_update_profile(&$action, &$user_data, &$current_user_data) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid)) {
		return;
	}
	
	$event_name = ($action == 'add') ? 'CustomerAdd' : 'CustomerUpdate';

	$event_data = array(
		'event' => $event_name,
		'uuid' => $routee_uuid,
		'data' => array(
			'customer' => array(
				'id' => $user_data['user_id'],
				'lastname' => $user_data['firstname'],
				'firstname' => $user_data['lastname'],
				'email' => $user_data['email'],
			),
			'addresses' => array(
				array(
					'country' => $user_data['b_country_descr'],
					'city' => $user_data['b_city'],
					'address1' => $user_data['b_address'],
					'postcode' => $user_data['b_zipcode'],
					'phone' => $user_data['b_phone'],
					'company' => $user_data['company'],
				),
				array(
					'country' => $user_data['s_country_descr'],
					'city' => $user_data['s_city'],
					'address1' => $user_data['s_address'],
					'postcode' => $user_data['s_zipcode'],
					'phone' => $user_data['s_phone'],
					'company' => $user_data['company'],
				),
			)
		)
	);

	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_routee_place_order(&$order_id, &$action, &$order_status, &$cart, &$auth) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid)) {
		return;
	}
	
	$order_info = fn_get_order_info($order_id);
	
	$event_data = array(
		'event' => 'OrderAdd',
		'uuid' => $routee_uuid,
		'data' => array(
			'customer_id' => $order_info['user_id'],
			'order_details' => array(
				'order_id' => $order_info['user_id'],
				'order_status' => db_get_field('SELECT ?:status_descriptions.description FROM ?:status_descriptions LEFT JOIN ?:statuses ON ?:status_descriptions.status_id = ?:statuses.status_id WHERE ?:statuses.status = ?s AND ?:statuses.type = ?s AND ?:status_descriptions.lang_code = ?s', ($order_info['status'] == 'N') ? 'O' : $order_info['status'], 'O', CART_LANGUAGE),
				'shipping_method' => db_get_field('SELECT ?:shipping_descriptions.shipping FROM ?:shipping_descriptions LEFT JOIN ?:shippings ON ?:shippings.shipping_id = ?:shippings.shipping_id WHERE ?:shippings.shipping_id = ?i AND ?:shipping_descriptions.lang_code = ?s', $order_info['shipping_ids'], CART_LANGUAGE),
				'payment_method' => isset($order_info['payment_method']['payment']) ? $order_info['payment_method']['payment'] : '',
				'total_price' => $order_info['total'],
			),
			'customer' => array(
				'id' => $order_info['user_id'],
				'lastname' => $order_info['firstname'],
				'firstname' => $order_info['lastname'],
				'email' => $order_info['email'],
			),
			'addresses' => array(
				array(
					'country' => $order_info['b_country_descr'],
					'city' => $order_info['b_city'],
					'address1' => $order_info['b_address'],
					'postcode' => $order_info['b_zipcode'],
					'phone' => $order_info['b_phone'],
					'company' => $order_info['company'],
				),
				array(
					'country' => $order_info['s_country_descr'],
					'city' => $order_info['s_city'],
					'address1' => $order_info['s_address'],
					'postcode' => $order_info['s_zipcode'],
					'phone' => $order_info['s_phone'],
					'company' => $order_info['company'],
				),
			)
		)
	);

	if (!empty($order_info['products'])) {
		foreach ($order_info['products'] as $v) {
			$event_data['data']['order_products'][] = array(
				'product_id' => $v['product_id'],
				'quantity' => $v['amount'],
			);
		}
	}

	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_routee_change_order_status($status_to, $status_from, $order_info, $force_notification, $order_statuses, $place_order) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid)) {
		return;
	}
	
	$event_data = array(
		'event' => 'OrderStatusUpdate',
		'uuid' => $routee_uuid,
		'data' => array(
			'customer_id' => $order_info['user_id'],
			'order_id' => $order_info['order_id'],
			'order_status' => db_get_field('SELECT ?:status_descriptions.description FROM ?:status_descriptions LEFT JOIN ?:statuses ON ?:status_descriptions.status_id = ?:statuses.status_id WHERE ?:statuses.status = ?s AND ?:statuses.type = ?s AND ?:status_descriptions.lang_code = ?s', $status_to, 'O', CART_LANGUAGE),
		)
	);

	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));
	
	if ($status_to != 'P' && $status_to != 'C') {
		return;
	}
	
	$event_data = array(
		'event' => 'OrderPaymentConfirmed',
		'uuid' => $routee_uuid,
		'data' => array(
			'customer_id' => $order_info['user_id'],
			'order_id' => $order_info['order_id'],
		)
	);

	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_routee_update_product_post(&$product_data, &$product_id, &$lang_code, &$create) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid)) {
		return;
	}

	$event_name = ($create) ? 'ProductAdd' : 'ProductUpdate';
	$image_pair = fn_get_image_pairs($product_id, 'product', 'M', true, true, $lang_code);
	$product_options = fn_get_product_options($product_id);

	$event_data = array(
		'event' => $event_name,
		'uuid' => $routee_uuid,
		'data' => array(
			'product_id' => $product_id,
			'name' => $product_data['product'],
			'description' => $product_data['full_description'],
			'short_description' => $product_data['short_description'],
			'stock_quantity' => $product_data['amount'],
			'price' => $product_data['price'],
			'image_link' => (!empty($image_pair)) ? $image_pair['detailed']['image_path'] : '',
			'product_link' => fn_url('products.view?product_id='.$product_id, 'C'),
		)
	);
	
	if (!empty($product_options)) {
		foreach ($product_options as $opt) {
			if (!empty($opt['variants'])) {
				foreach ($opt['variants'] as $var) {
					$event_data['data']['product_options'][] = array(
						'option_id' => $opt['option_id'],
						'option_name' => $opt['option_name'],
						'varian_name' => $var['variant_name'],
						'price_modifier' => $var['modifier'],
					);
				}
			}
		}
	}
	
	if (!empty($product_data['category_ids'])) {
		foreach ($product_data['category_ids'] as $v) {
			$event_data['data']['categories'][] = fn_get_category_name($v, $lang_code);
		}
	}

	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_routee_update_product_amount(&$new_amount, &$product_id, &$cart_id, &$tracking, &$notify) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid)) {
		return;
	}
	
	$event_data = array(
		'event' => 'ProductStockUpdate',
		'uuid' => $routee_uuid,
		'data' => array(
			'product_id' => $product_id,
			'stock_quantity' => $new_amount,
		)
	);

	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

	if ($new_amount > 0) {
		return;
	}
	
	$event_data = array(
		'event' => 'ProductOutOfStock',
		'uuid' => $routee_uuid,
		'data' => array(
			'product_id' => $product_id,
		)
	);

	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_routee_pre_add_to_wishlist(&$product_data, &$wishlist, &$auth) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid) || empty($product_data)) {
		return;
	}
	
	foreach ($product_data as $v) {
		
		$event_data = array(
			'event' => 'WishlistAdd',
			'uuid' => $routee_uuid,
			'data' => array(
				'product_id' => $v['product_id'],
				'customer_id' => $auth['user_id'],
			)
		);

		$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

	}

}

function fn_routee_delete_wishlist_product(&$wishlist, &$wishlist_id) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid) || !isset($wishlist['products'][$wishlist_id])) {
		return;
	}
	
	$event_data = array(
		'event' => 'WishlistDelete',
		'uuid' => $routee_uuid,
		'data' => array(
			'product_id' => $wishlist['products'][$wishlist_id]['product_id'],
			'customer_id' => $_SESSION['auth']['user_id'],
		)
	);

	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_routee_save_cart_content_post(&$cart, &$user_id, &$type, &$user_type) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid) || $type != 'C') {
		return;
	}
	
	$event_data = array(
		'event' => 'CartUpdate',
		'uuid' => $routee_uuid,
		'data' => array(
			'customer_id' => $_SESSION['auth']['user_id'],
			'cart_products' => array()
		)
	);
	
	if (isset($cart['products']) && !empty($cart['products'])) {
		foreach ($cart['products'] as $v) {
			$event_data['data']['cart_products'][] = array(
				'product_id' => $v['product_id'],
				'quantity' => $v['amount'],
			);
		}
	}
	
	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_routee_newsletters_update_subscriptions_post(&$subscriber_id, &$user_list_ids, &$subscriber, &$params) {

	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid) || empty($subscriber['email'])) {
		return;
	}
	
	$event_data = array(
		'event' => 'Newsletter',
		'uuid' => $routee_uuid,
		'data' => array(
			'customer_id' => $_SESSION['auth']['user_id'],
			'email' => $subscriber['email'],
			'subscription' => 'true',
		)
	);
	
	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_routee_get_products(&$params, &$fields, &$sortings, &$condition, &$join, &$sorting, &$group_by, &$lang_code, &$having) {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid) || !isset($params['q']) || empty($params['q'])) {
		return;
	}
	
	$event_data = array(
		'event' => 'Search',
		'uuid' => $routee_uuid,
		'data' => array(
			'customer_id' => $_SESSION['auth']['user_id'],
			'search_string' => $params['q'],
		)
	);
	
	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));

}

function fn_get_account_creation_notice() {

    return __('routee.account_creation_notice');

}

function fn_uninstall_routee() {
	
	$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
	
	if (empty($routee_uuid)) {
		return;
	}
	
	$event_data = array(
		'event' => 'Uninstall',
		'uuid' => $routee_uuid,
		'data' => array()
	);
	
	$return = Http::post('https://idata.routee.net/api/event', json_encode($event_data));
	
	db_query('DELETE FROM ?:common_descriptions WHERE object_holder = ?s', 'routee_uuid');

}